@@ -1,7 +1,6 @@
 // This file is released into Public Domain.
 extern crate gnuplot;
 
-
 use gnuplot::*;
 use std::thread::sleep;
 use std::time::Duration;
@@ -20,7 +19,9 @@ fn main()
 	loop
 	{
 		fg.clear_axes();
-		fg.axes2d().set_y_range(Fix(-1.0), Fix(1.0)).lines(x.iter(), x.iter().map(|&x| (x + t).sin()), &[]);
+		fg.axes2d()
+			.set_y_range(Fix(-1.0), Fix(1.0))
+			.lines(x.iter(), x.iter().map(|&x| (x + t).sin()), &[]);
 		t += 0.1;
 		fg.show();
 		sleep(Duration::from_millis(500));
