@@ -37,7 +37,12 @@ fn example(c: Common)
 		.set_title("Example Plot fg1.1", &[])
 		.set_x_ticks(Some((Fix(1.0), 1)), &[Mirror(false)], &[])
 		.set_y_ticks(Some((Fix(1.0), 1)), &[Mirror(false)], &[])
-		.set_legend(Graph(1.0), Graph(0.5), &[Placement(AlignLeft, AlignCenter)], &[TextAlign(AlignRight)])
+		.set_legend(
+			Graph(1.0),
+			Graph(0.5),
+			&[Placement(AlignLeft, AlignCenter)],
+			&[TextAlign(AlignRight)],
+		)
 		.set_border(true, &[Left, Bottom], &[LineWidth(2.0)])
 		.set_x_label("Abscissa", &[])
 		.set_y_label("Ordinate", &[])
@@ -52,7 +57,17 @@ fn example(c: Common)
 		.fill_between(x, y1.map(|&y| y * 0.85 - 1.0), y1.map(|&y| y * 1.15 + 1.0), &[Color("#aaaaff")])
 		.lines(x, y1, &[Caption("(x - 4)^2 - 5"), LineWidth(1.5), Color("black")])
 		.y_error_lines(x, y2, repeat(1.0f32), &[Caption("(x - 4)^2 + 5"), LineWidth(1.5), Color("red")])
-		.lines_points(x, y3, &[Caption("x - 4"), PointSymbol('t'), LineWidth(1.5), LineStyle(Dash), Color("#11ff11")]);
+		.lines_points(
+			x,
+			y3,
+			&[
+				Caption("x - 4"),
+				PointSymbol('t'),
+				LineWidth(1.5),
+				LineStyle(Dash),
+				Color("#11ff11"),
+			],
+		);
 
 	c.show(&mut fg, "fg1.1.gnuplot");
 
@@ -134,7 +149,12 @@ fn example(c: Common)
 		.set_pos(0.0, 0.2)
 		.fill_between(x, y1, y3, &[Color("red"), FillAlpha(0.5), FillRegion(Above), Caption("A > B")])
 		.fill_between(x, y1, y3, &[Color("green"), FillAlpha(0.5), FillRegion(Below), Caption("A < B")])
-		.fill_between(x, y2, y3, &[Color("blue"), FillAlpha(0.5), FillRegion(Between), Caption("Between C and B")])
+		.fill_between(
+			x,
+			y2,
+			y3,
+			&[Color("blue"), FillAlpha(0.5), FillRegion(Between), Caption("Between C and B")],
+		)
 		.lines(x, y1, &[Color("black"), LineWidth(2.0), LineStyle(Dash), Caption("A")])
 		.lines(x, y2, &[Color("black"), LineWidth(2.0), Caption("C")])
 		.lines(x, y3, &[Color("black"), LineWidth(2.0), LineStyle(DotDotDash), Caption("B")])
@@ -154,12 +174,19 @@ fn example(c: Common)
 	fg.axes2d()
 		.set_pos(0.1, 0.1)
 		.set_size(0.8, 0.8)
-		.lines(x, y1, &[Caption("(x - 4)^2 - 5"), LineWidth(3.0), Color("violet"), LineStyle(DotDash)])
+		.lines(
+			x,
+			y1,
+			&[Caption("(x - 4)^2 - 5"), LineWidth(3.0), Color("violet"), LineStyle(DotDash)],
+		)
 		.points(x, y2, &[Caption("(x - 4)^2 + 5"), PointSymbol('S'), Color("#ffaa77")])
 		.lines_points(x, y3, &[Caption("x - 4"), PointSymbol('O'), Color("black"), LineStyle(SmallDot)])
 		.set_x_label("X Label", &[Font("Arial", 24.0), TextColor("red"), Rotate(45.0)])
 		.set_y_label("Y Label", &[Rotate(0.0)])
-		.set_title("Goings nuts with the formatting fg1.7", &[Font("Times", 24.0), TextOffset(-10.0, 0.5)])
+		.set_title(
+			"Goings nuts with the formatting fg1.7",
+			&[Font("Times", 24.0), TextOffset(-10.0, 0.5)],
+		)
 		.label(
 			"Intersection",
 			Axis(2.208),
