@@ -2,7 +2,6 @@
 //
 // All rights reserved. Distributed under LGPL 3.0. For full terms see the file LICENSE.
 
-
 use axes_common::*;
 use datatype::*;
 use options::*;
@@ -50,8 +49,9 @@ impl Axes3D
 	///                  By default this will be `(0, 0)` and `(num_rows - 1, num_cols - 1)`.
 	/// * `options` - Array of PlotOption controlling the appearance of the surface. Relevant options are:
 	///     * `Caption` - Specifies the caption for this dataset. Use an empty string to hide it (default).
-	pub fn surface<'l, T: DataType, X: IntoIterator<Item = T>>(&'l mut self, mat: X, num_rows: usize, num_cols: usize, dimensions: Option<(f64, f64, f64, f64)>, options: &[PlotOption<&str>])
-		-> &'l mut Self
+	pub fn surface<'l, T: DataType, X: IntoIterator<Item = T>>(
+		&'l mut self, mat: X, num_rows: usize, num_cols: usize, dimensions: Option<(f64, f64, f64, f64)>, options: &[PlotOption<&str>],
+	) -> &'l mut Self
 	{
 		self.common.elems.push(PlotElement::new_plot_matrix(
 			Pm3D,
@@ -65,6 +65,86 @@ impl Axes3D
 		self
 	}
 
+	/// Plot a 3D scatter-plot with a point standing in for each data point
+	/// # Arguments
+	/// * `x` - x values
+	/// * `y` - y values
+	/// * `z` - z values
+	/// * `options` - Array of PlotOption<&str> controlling the appearance of the plot element. The relevant options are:
+	///     * `Caption` - Specifies the caption for this dataset. Use an empty string to hide it (default).
+	///     * `PointSymbol` - Sets symbol for each point
+	///     * `PointSize` - Sets the size of each point
+	///     * `Color` - Sets the color
+	pub fn points<
+		'l,
+		Tx: DataType,
+		X: IntoIterator<Item = Tx>,
+		Ty: DataType,
+		Y: IntoIterator<Item = Ty>,
+		Tz: DataType,
+		Z: IntoIterator<Item = Tz>,
+	>(
+		&'l mut self, x: X, y: Y, z: Z, options: &[PlotOption<&str>],
+	) -> &'l mut Self
+	{
+		self.common
+			.elems
+			.push(PlotElement::new_plot3(Points, x, y, z, options.to_one_way_owned()));
+		self
+	}
+
+	/// Plot a 3D scatter-plot with lines connecting each data point
+	/// # Arguments
+	/// * `x` - x values
+	/// * `y` - y values
+	/// * `z` - z values
+	/// * `options` - Array of PlotOption<&str> controlling the appearance of the plot element. The relevant options are:
+	///     * `Caption` - Specifies the caption for this dataset. Use an empty string to hide it (default).
+	///     * `PointSymbol` - Sets symbol for each point
+	///     * `PointSize` - Sets the size of each point
+	///     * `Color` - Sets the color
+	pub fn lines<
+		'l,
+		Tx: DataType,
+		X: IntoIterator<Item = Tx>,
+		Ty: DataType,
+		Y: IntoIterator<Item = Ty>,
+		Tz: DataType,
+		Z: IntoIterator<Item = Tz>,
+	>(
+		&'l mut self, x: X, y: Y, z: Z, options: &[PlotOption<&str>],
+	) -> &'l mut Self
+	{
+		self.common
+			.elems
+			.push(PlotElement::new_plot3(Lines, x, y, z, options.to_one_way_owned()));
+		self
+	}
+
+	/// A combination of lines and points methods (drawn in that order).
+	/// # Arguments
+	/// * `x` - x values
+	/// * `y` - y values
+	/// * `z` - z values
+	/// * `options` - Array of PlotOption<&str> controlling the appearance of the plot element
+	pub fn lines_points<
+		'l,
+		Tx: DataType,
+		X: IntoIterator<Item = Tx>,
+		Ty: DataType,
+		Y: IntoIterator<Item = Ty>,
+		Tz: DataType,
+		Z: IntoIterator<Item = Tz>,
+	>(
+		&'l mut self, x: X, y: Y, z: Z, options: &[PlotOption<&str>],
+	) -> &'l mut Self
+	{
+		self.common
+			.elems
+			.push(PlotElement::new_plot3(LinesPoints, x, y, z, options.to_one_way_owned()));
+		self
+	}
+
 	/// Sets the 3D view.
 	///
 	/// #Arguments:
@@ -111,8 +191,9 @@ impl Axes3D
 	}
 
 	/// Like `set_x_ticks_custom` but for the the Y axis.
-	pub fn set_z_ticks_custom<'l, T: DataType, TL: IntoIterator<Item = Tick<T>>>(&'l mut self, ticks: TL, tick_options: &[TickOption<&str>], label_options: &[LabelOption<&str>])
-		-> &'l mut Self
+	pub fn set_z_ticks_custom<'l, T: DataType, TL: IntoIterator<Item = Tick<T>>>(
+		&'l mut self, ticks: TL, tick_options: &[TickOption<&str>], label_options: &[LabelOption<&str>],
+	) -> &'l mut Self
 	{
 		self.z_axis
 			.set_ticks_custom(ticks, tick_options.to_one_way_owned(), label_options.to_one_way_owned());
@@ -137,7 +218,6 @@ impl Axes3D
 		self
 	}
 
-
 	/// Sets the Z axis be logarithmic. Note that the range must be non-negative for this to be valid.
 	///
 	/// # Arguments
@@ -168,8 +248,9 @@ impl Axes3D
 	///             otherwise an empty string disables the legend and labels.
 	/// * `levels` - Auto picks some default number of levels, otherwise you can pass a set nominal number instead. The number is nominal as
 	///              contours are placed at nice values of Z, and thus there may be fewer of them than this number.
-	pub fn show_contours<'l>(&'l mut self, base: bool, surface: bool, style: ContourStyle, label: AutoOption<&str>, levels: AutoOption<u32>)
-		-> &'l mut Self
+	pub fn show_contours<'l>(
+		&'l mut self, base: bool, surface: bool, style: ContourStyle, label: AutoOption<&str>, levels: AutoOption<u32>,
+	) -> &'l mut Self
 	{
 		self.contour_base = base;
 		self.contour_surface = surface;
@@ -189,8 +270,9 @@ impl Axes3D
 	/// * `label` - Auto sets the label automatically and enables the legend, Fix() allows you specify a format string (using C style formatting),
 	///             otherwise an empty string disables the legend and labels.
 	/// * `levels` - A set of levels.
-	pub fn show_contours_custom<'l, T: DataType, TC: IntoIterator<Item = T>>(&'l mut self, base: bool, surface: bool, style: ContourStyle, label: AutoOption<&str>, levels: TC)
-		-> &'l mut Self
+	pub fn show_contours_custom<'l, T: DataType, TC: IntoIterator<Item = T>>(
+		&'l mut self, base: bool, surface: bool, style: ContourStyle, label: AutoOption<&str>, levels: TC,
+	) -> &'l mut Self
 	{
 		self.contour_base = base;
 		self.contour_surface = surface;
